summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorDessalines <tyhou13@gmx.com>2020-06-10 18:22:57 -0400
committerDessalines <tyhou13@gmx.com>2020-06-10 18:22:57 -0400
commit2fbd44c59db9c94f7cd2055550066f429a19154b (patch)
tree3a42c510222f874d010b62fe5bcbb62897386dec
parentbd26e4e9c1b146163ee839de0a45bb9354efd1f2 (diff)
Adding pictrs thumbnail caching for urls and embeds.
-rw-r--r--server/src/api/mod.rs2
-rw-r--r--server/src/api/post.rs4
-rw-r--r--server/src/lib.rs48
3 files changed, 32 insertions, 22 deletions
diff --git a/server/src/api/mod.rs b/server/src/api/mod.rs
index 3488a8c4..4f11b327 100644
--- a/server/src/api/mod.rs
+++ b/server/src/api/mod.rs
@@ -18,7 +18,7 @@ use crate::db::user_mention_view::*;
use crate::db::user_view::*;
use crate::db::*;
use crate::{
- extract_usernames, fetch_iframely_and_pictshare_data, generate_random_string, naive_from_unix,
+ extract_usernames, fetch_iframely_and_pictrs_data, generate_random_string, naive_from_unix,
naive_now, remove_slurs, send_email, slur_check, slurs_vec_to_str,
};
diff --git a/server/src/api/post.rs b/server/src/api/post.rs
index 84ef89f1..0e8a17e7 100644
--- a/server/src/api/post.rs
+++ b/server/src/api/post.rs
@@ -118,7 +118,7 @@ impl Perform for Oper<CreatePost> {
// Fetch Iframely and Pictshare cached image
let (iframely_title, iframely_description, iframely_html, pictshare_thumbnail) =
- fetch_iframely_and_pictshare_data(data.url.to_owned());
+ fetch_iframely_and_pictrs_data(data.url.to_owned());
let post_form = PostForm {
name: data.name.to_owned(),
@@ -452,7 +452,7 @@ impl Perform for Oper<EditPost> {
// Fetch Iframely and Pictshare cached image
let (iframely_title, iframely_description, iframely_html, pictshare_thumbnail) =
- fetch_iframely_and_pictshare_data(data.url.to_owned());
+ fetch_iframely_and_pictrs_data(data.url.to_owned());
let post_form = PostForm {
name: data.name.to_owned(),
diff --git a/server/src/lib.rs b/server/src/lib.rs
index ca4bedea..9b73caa8 100644
--- a/server/src/lib.rs
+++ b/server/src/lib.rs
@@ -187,25 +187,35 @@ pub fn fetch_iframely(url: &str) -> Result<IframelyResponse, failure::Error> {
Ok(res)
}
-#[derive(Deserialize, Debug)]
-pub struct PictshareResponse {
- status: String,
- url: String,
+#[derive(Deserialize, Debug, Clone)]
+pub struct PictrsResponse {
+ files: Vec<PictrsFile>,
+ msg: String,
+}
+
+#[derive(Deserialize, Debug, Clone)]
+pub struct PictrsFile {
+ file: String,
+ delete_token: String,
}
-pub fn fetch_pictshare(image_url: &str) -> Result<PictshareResponse, failure::Error> {
+pub fn fetch_pictrs(image_url: &str) -> Result<PictrsResponse, failure::Error> {
is_image_content_type(image_url)?;
let fetch_url = format!(
- "http://pictshare/api/geturl.php?url={}",
- utf8_percent_encode(image_url, NON_ALPHANUMERIC)
+ "http://pictrs:8080/image/download?url={}",
+ utf8_percent_encode(image_url, NON_ALPHANUMERIC) // TODO this might not be needed
);
let text = isahc::get(&fetch_url)?.text()?;
- let res: PictshareResponse = serde_json::from_str(&text)?;
- Ok(res)
+ let res: PictrsResponse = serde_json::from_str(&text)?;
+ if res.msg == "ok" {
+ Ok(res)
+ } else {
+ Err(format_err!("{}", &res.msg))
+ }
}
-fn fetch_iframely_and_pictshare_data(
+fn fetch_iframely_and_pictrs_data(
url: Option<String>,
) -> (
Option<String>,
@@ -225,20 +235,20 @@ fn fetch_iframely_and_pictshare_data(
}
};
- // Fetch pictshare thumbnail
- let pictshare_thumbnail = match iframely_thumbnail_url {
- Some(iframely_thumbnail_url) => match fetch_pictshare(&iframely_thumbnail_url) {
- Ok(res) => Some(res.url),
+ // Fetch pictrs thumbnail
+ let pictrs_thumbnail = match iframely_thumbnail_url {
+ Some(iframely_thumbnail_url) => match fetch_pictrs(&iframely_thumbnail_url) {
+ Ok(res) => Some(res.files[0].file.to_owned()),
Err(e) => {
- error!("pictshare err: {}", e);
+ error!("pictrs err: {}", e);
None
}
},
// Try to generate a small thumbnail if iframely is not supported
- None => match fetch_pictshare(&url) {
- Ok(res) => Some(res.url),
+ None => match fetch_pictrs(&url) {
+ Ok(res) => Some(res.files[0].file.to_owned()),
Err(e) => {
- error!("pictshare err: {}", e);
+ error!("pictrs err: {}", e);
None
}
},
@@ -248,7 +258,7 @@ fn fetch_iframely_and_pictshare_data(
iframely_title,
iframely_description,
iframely_html,
- pictshare_thumbnail,
+ pictrs_thumbnail,
)
}
None => (None, None, None, None),